==> scilab_5.2.1.orig.tar.gz: scilab-5.2.1/modules/gui/src/java/org/scilab/modules/gui/bridge/tree/SwingScilabTree.java <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2009 - DIGITEO - Sylvestre KOUMAR
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

package org.scilab.modules.gui.bridge.tree;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.Vector;

import javax.swing.Icon;
import javax.swing.JComponent;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreePath;

import org.scilab.modules.gui.bridge.tab.SwingScilabTab;
import org.scilab.modules.gui.events.callback.CallBack;
import org.scilab.modules.gui.menubar.MenuBar;
import org.scilab.modules.gui.tab.ScilabTab;
import org.scilab.modules.gui.tab.Tab;
import org.scilab.modules.gui.textbox.TextBox;
import org.scilab.modules.gui.toolbar.ToolBar;
import org.scilab.modules.gui.tree.SimpleTree;
import org.scilab.modules.gui.tree.Tree;
import org.scilab.modules.gui.utils.Position;
import org.scilab.modules.gui.utils.PositionConverter;
import org.scilab.modules.gui.utils.Size;
import org.scilab.modules.gui.window.ScilabWindow;
import org.scilab.modules.gui.window.Window;
import org.scilab.modules.localization.Messages;

public class SwingScilabTree extends DefaultMutableTreeNode implements SimpleTree {

	private static final long serialVersionUID = 1L;
	
	private Icon icon;
	private CallBack callback;
	private JScrollPane scrollPane = new JScrollPane();

	/**
	 * Default constructor
	 * @param tree structure to display
	 */
	public SwingScilabTree(Tree tree) {
		super(tree.getLabel());
		this.setIcon(tree.getIcon());
		this.setCallback(tree.getCallback());
		
		Vector<Tree> children = tree.getChildren();
		
		for (int i = 0 ; i < children.size() ; ++i)	{
			SwingScilabTree swingScilabTree = new SwingScilabTree(children.get(i));
			this.add(swingScilabTree);
		}
	}
	
	public Icon getIcon() {
		return icon;
	}

	public void setIcon(Icon icon) {
		this.icon = icon;
	}
	
	public CallBack getCallback() {
		return callback;
	}

	public void setCallback(CallBack callback) {
		this.callback = callback;
	}

	/**
	 *  This is a private class to embed the JTree inside its Mouse Listener
	 *  in order we can figure out on which leaff the user clicked on.
	 */
	private class ClickListener extends MouseAdapter {
	    private JTree _jtree;
	    
	    public ClickListener(JTree jtree) {
		_jtree = jtree;
	    }
	    
	    public void mouseClicked(MouseEvent arg0) {
		TreePath path = _jtree.getPathForLocation(arg0.getX(),arg0.getY());
		/* We only want double click to do something */
		if (path != null && arg0.getClickCount() >= 2) {
		    ((SwingScilabTree) path.getLastPathComponent()).getCallback().actionPerformed(null);
		}

	    }
	}
	
	public JComponent getAsComponent() {
		// Tree Model
		DefaultTreeModel model = new DefaultTreeModel(this);		
		// Renderer
		ScilabTreeCellRenderer renderer = new ScilabTreeCellRenderer();
		// Swing tree component
		JTree jtree = new JTree();	
		// Show Root Handles
		jtree.setShowsRootHandles(true);
		// Set model to the JTree
		jtree.setModel(model);		
		// Set renderer
		jtree.setCellRenderer(renderer);

		jtree.addMouseListener(new ClickListener(jtree));
		jtree.setVisible(true);
		
		
		scrollPane.getViewport().add(jtree);
		return scrollPane;
	}
	
	public static void  showTree(Tree tree) {
		
		// Scilab tree
		SwingScilabTree swingScilabTree = new SwingScilabTree(tree);
		
		Window window = ScilabWindow.createWindow();
		final Tab tab = ScilabTab.createTab(Messages.gettext("Tree Overview"));
		tab.setCallback(new CallBack(null) {
			private static final long serialVersionUID = 8418506008885202932L;

			public void callBack() {
				tab.close();
			}
		});
		((SwingScilabTab) tab.getAsSimpleTab()).addTree(swingScilabTree);
		window.addTab(tab);
		tab.setVisible(true);
		window.setVisible(true);
	}

	public void destroy() {
		// TODO Auto-generated method stub
		
	}

	public Color getBackground() {
		// TODO Auto-generated method stub
		return null;
	}

	public Font getFont() {
		// TODO Auto-generated method stub
		return null;
	}

	public Color getForeground() {
		// TODO Auto-generated method stub
		return null;
	}

	public String getText() {
		// TODO Auto-generated method stub
		return null;
	}

	public boolean isEnabled() {
		// TODO Auto-generated method stub
		return false;
	}

	public void requestFocus() {
		// TODO Auto-generated method stub
		
	}

	public void setBackground(Color color) {
		// TODO Auto-generated method stub
		
	}

	public void setEnabled(boolean status) {
		// TODO Auto-generated method stub
		
	}

	public void setFont(Font font) {
		// TODO Auto-generated method stub
		
	}

	public void setForeground(Color color) {
		// TODO Auto-generated method stub
		
	}

	public void setHorizontalAlignment(String alignment) {
		// TODO Auto-generated method stub
		
	}

	public void setRelief(String reliefType) {
		// TODO Auto-generated method stub
		
	}

	public void setText(String text) {
		// TODO Auto-generated method stub
		
	}

	public void setVerticalAlignment(String alignment) {
		// TODO Auto-generated method stub
		
	}

	public void addInfoBar(TextBox infoBarToAdd) {
		// TODO Auto-generated method stub
		
	}

	public void addMenuBar(MenuBar menuBarToAdd) {
		// TODO Auto-generated method stub
		
	}

	public void addToolBar(ToolBar toolBarToAdd) {
		// TODO Auto-generated method stub
		
	}

	public void draw() {
		// TODO Auto-generated method stub
		
	}

	public Size getDims() {
	    return new Size(scrollPane.getSize().width, scrollPane.getSize().height);
	}

	public TextBox getInfoBar() {
		// TODO Auto-generated method stub
		return null;
	}

	public MenuBar getMenuBar() {
		// TODO Auto-generated method stub
		return null;
	}

	public Position getPosition() {
	    return PositionConverter.javaToScilab(scrollPane.getLocation(), scrollPane.getSize(), scrollPane.getParent());
	}

	public ToolBar getToolBar() {
		// TODO Auto-generated method stub
		return null;
	}

	public boolean isVisible() {
		// TODO Auto-generated method stub
		return false;
	}

	public void setDims(Size newSize) {
	    scrollPane.setSize(new Dimension(newSize.getWidth(), newSize.getHeight()));
	}

	public void setPosition(Position newPosition) {
	    Position javaPosition = PositionConverter.scilabToJava(newPosition, this.getDims(), scrollPane.getParent());
	    scrollPane.setLocation(javaPosition.getX(), javaPosition.getY());
	}

	public void setVisible(boolean newVisibleState) {
		// TODO Auto-generated method stub
		
	}
}

==> scilab_5.3.3.orig.tar.gz: scilab-5.3.3/modules/gui/src/java/org/scilab/modules/gui/bridge/tree/SwingScilabTree.java <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2009 - DIGITEO - Sylvestre KOUMAR
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

package org.scilab.modules.gui.bridge.tree;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.Vector;

import javax.swing.Icon;
import javax.swing.JComponent;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreePath;

import org.scilab.modules.gui.bridge.tab.SwingScilabTab;
import org.scilab.modules.gui.events.callback.CallBack;
import org.scilab.modules.gui.menubar.MenuBar;
import org.scilab.modules.gui.tab.ScilabTab;
import org.scilab.modules.gui.tab.Tab;
import org.scilab.modules.gui.textbox.TextBox;
import org.scilab.modules.gui.toolbar.ToolBar;
import org.scilab.modules.gui.tree.SimpleTree;
import org.scilab.modules.gui.tree.Tree;
import org.scilab.modules.gui.utils.Position;
import org.scilab.modules.gui.utils.PositionConverter;
import org.scilab.modules.gui.utils.Size;
import org.scilab.modules.gui.window.ScilabWindow;
import org.scilab.modules.gui.window.Window;
import org.scilab.modules.localization.Messages;

/**
 * Class define the Scilab Mutable tree node
 * @author Sylvestre Koumar
 *
 */
public class SwingScilabTree extends DefaultMutableTreeNode implements SimpleTree {

	private static final long serialVersionUID = 1L;
	
	private Icon icon;
	private CallBack callback;
	private JScrollPane scrollPane = new JScrollPane();

	/**
	 * Default constructor
	 * @param tree structure to display
	 */
	public SwingScilabTree(Tree tree) {
		super(tree.getLabel());
		this.setIcon(tree.getIcon());
		this.setCallback(tree.getCallback());
		
		Vector<Tree> children = tree.getChildren();
		
		for (int i = 0; i < children.size(); ++i)	{
			SwingScilabTree swingScilabTree = new SwingScilabTree(children.get(i));
			this.add(swingScilabTree);
		}
	}
	
	/**
	 * Getter for icon
	 * @return an icon
	 */
	public Icon getIcon() {
		return icon;
	}

	/**
	 * Setter for icon
	 * @param icon an Icon
	 */
	public void setIcon(Icon icon) {
		this.icon = icon;
	}
	
	/**
	 * Getter for callback
	 * @return a callback
	 */
	public CallBack getCallback() {
		return callback;
	}

	/**
	 * Setter for callback
	 * @param callback a callback
	 */
	public void setCallback(CallBack callback) {
		this.callback = callback;
	}

	/**
	 *  This is a private class to embed the JTree inside its Mouse Listener
	 *  in order we can figure out on which leaff the user clicked on.
	 */
	private class ClickListener extends MouseAdapter {
	    private JTree myJtree;
	    
	    /**
	     * Constructor
	     * @param jtree a Jtree
	     */
	    public ClickListener(JTree jtree) {
		myJtree = jtree;
	    }
	    
	    /**
	     * Mouse clicked actions
	     * @param arg0 event
	     */
	    public void mouseClicked(MouseEvent arg0) {
		TreePath path = myJtree.getPathForLocation(arg0.getX(), arg0.getY());
		/* We only want double click to do something */
		if (path != null && arg0.getClickCount() >= 2) {
		    ((SwingScilabTree) path.getLastPathComponent()).getCallback().actionPerformed(null);
		}

	    }
	}
	
	/**
	 * Get as Component
	 * @return a component
	 */
	public JComponent getAsComponent() {
		// Tree Model
		DefaultTreeModel model = new DefaultTreeModel(this);		
		// Renderer
		ScilabTreeCellRenderer renderer = new ScilabTreeCellRenderer();
		// Swing tree component
		JTree jtree = new JTree();	
		// Show Root Handles
		jtree.setShowsRootHandles(true);
		// Set model to the JTree
		jtree.setModel(model);		
		// Set renderer
		jtree.setCellRenderer(renderer);

		jtree.addMouseListener(new ClickListener(jtree));
		jtree.setVisible(true);
		
		
		scrollPane.getViewport().add(jtree);
		return scrollPane;
	}
	
	/**
	 * Display the tree
	 * @param tree a tree
	 */
	public static void  showTree(Tree tree) {
		
		// Scilab tree
		SwingScilabTree swingScilabTree = new SwingScilabTree(tree);
		
		Window window = ScilabWindow.createWindow();
		final Tab tab = ScilabTab.createTab(Messages.gettext("Tree Overview"));
		tab.setCallback(new CallBack(null) {
			private static final long serialVersionUID = 8418506008885202932L;

			public void callBack() {
				tab.close();
			}
		});
		((SwingScilabTab) tab.getAsSimpleTab()).addTree(swingScilabTree);
		window.addTab(tab);
		tab.setVisible(true);
		window.setVisible(true);
	}

	public void destroy() {
		// TODO Auto-generated method stub
		
	}

	public Color getBackground() {
		// TODO Auto-generated method stub
		return null;
	}

	public Font getFont() {
		// TODO Auto-generated method stub
		return null;
	}

	public Color getForeground() {
		// TODO Auto-generated method stub
		return null;
	}

	public String getText() {
		// TODO Auto-generated method stub
		return null;
	}

	public boolean isEnabled() {
		// TODO Auto-generated method stub
		return false;
	}

	public void requestFocus() {
		// TODO Auto-generated method stub
		
	}

	public void setBackground(Color color) {
		// TODO Auto-generated method stub
		
	}

	public void setEnabled(boolean status) {
		// TODO Auto-generated method stub
		
	}

	public void setFont(Font font) {
		// TODO Auto-generated method stub
		
	}

	public void setForeground(Color color) {
		// TODO Auto-generated method stub
		
	}

	public void setHorizontalAlignment(String alignment) {
		// TODO Auto-generated method stub
		
	}

	public void setRelief(String reliefType) {
		// TODO Auto-generated method stub
		
	}

	public void setText(String text) {
		// TODO Auto-generated method stub
		
	}

	public void setVerticalAlignment(String alignment) {
		// TODO Auto-generated method stub
		
	}

	public void addInfoBar(TextBox infoBarToAdd) {
		// TODO Auto-generated method stub
		
	}

	public void addMenuBar(MenuBar menuBarToAdd) {
		// TODO Auto-generated method stub
		
	}

	public void addToolBar(ToolBar toolBarToAdd) {
		// TODO Auto-generated method stub
		
	}

	public void draw() {
		// TODO Auto-generated method stub
		
	}

	/**
	 * Get size
	 * @return the size
	 */
	public Size getDims() {
	    return new Size(scrollPane.getSize().width, scrollPane.getSize().height);
	}

	public TextBox getInfoBar() {
		// TODO Auto-generated method stub
		return null;
	}

	public MenuBar getMenuBar() {
		// TODO Auto-generated method stub
		return null;
	}

	/**
	 * Get position
	 * @return the position
	 */
	public Position getPosition() {
	    return PositionConverter.javaToScilab(scrollPane.getLocation(), scrollPane.getSize(), scrollPane.getParent());
	}

	public ToolBar getToolBar() {
		// TODO Auto-generated method stub
		return null;
	}

	public boolean isVisible() {
		// TODO Auto-generated method stub
		return false;
	}

	/**
	 * Set size
	 * @param newSize a new size
	 */
	public void setDims(Size newSize) {
	    scrollPane.setSize(new Dimension(newSize.getWidth(), newSize.getHeight()));
	}

	/**
	 * Set position
	 * @param newPosition a new position
	 */
	public void setPosition(Position newPosition) {
	    Position javaPosition = PositionConverter.scilabToJava(newPosition, this.getDims(), scrollPane.getParent());
	    scrollPane.setLocation(javaPosition.getX(), javaPosition.getY());
	}

	public void setVisible(boolean newVisibleState) {
		// TODO Auto-generated method stub
		
	}
}
